@@ -50,6 +50,9 @@ static int               message_info_save (CamelFolderSummary *summary,
 					    CamelMessageInfo *info);
 static CamelMessageInfo *message_info_new_from_header  (CamelFolderSummary *summary,
 							struct _camel_header_raw *h);
+
+static void message_info_free (CamelFolderSummary *summary, CamelMessageInfo *info);
+
 static gboolean check_for_trash (CamelFolder *folder);
 static gboolean expunge_mail (CamelFolder *folder, CamelMessageInfo *info);
 
@@ -71,7 +74,8 @@ exchange_summary_class_init (CamelObjectClass *klass)
 	camel_folder_summary_class->message_info_load = message_info_load;
 	camel_folder_summary_class->message_info_save = message_info_save;
 	camel_folder_summary_class->message_info_new_from_header = message_info_new_from_header;
-
+	camel_folder_summary_class->message_info_free = message_info_free;
+	
 	camel_folder_summary_class->info_set_flags = info_set_flags;
 	camel_folder_summary_class->info_set_user_tag = info_set_user_tag;
 }
@@ -161,7 +165,7 @@ header_load (CamelFolderSummary *summary, FILE *in)
 	exchange->version = version;
 
 
-	d(g_print ("%s:%s:%d: high_article_num = [%d]\n", __FILE__, G_GNUC_PRETTY_FUNCTION, __LINE__, high_article_num));
+	d(g_print ("%s:%s: high_article_num = [%d]\n", G_STRLOC, G_STRFUNC, high_article_num));
 
 	return 0;
 }
@@ -183,7 +187,7 @@ header_save (CamelFolderSummary *summary, FILE *out)
 	if (camel_file_util_encode_uint32 (out, exchange->high_article_num) == -1)
 		return -1;
 
-	d(g_print ("%s:%s:%d: high_article_num = [%d]\n", __FILE__, G_GNUC_PRETTY_FUNCTION, __LINE__, exchange->high_article_num));
+	d(g_print ("%s:%s: high_article_num = [%d]\n", G_STRLOC, G_STRFUNC, exchange->high_article_num));
 
 	return 0;
 }
@@ -216,7 +220,7 @@ message_info_load (CamelFolderSummary *summary, FILE *in)
 		}
 
 		einfo->href = href;
-		d(g_print ("%s:%s:%d: einfo->href = [%s]\n", __FILE__, G_GNUC_PRETTY_FUNCTION, __LINE__, einfo->href));
+		d(g_print ("%s:%s: einfo->href = [%s]\n", G_STRLOC, G_STRFUNC, einfo->href));
 	}
 
 	return info;
@@ -239,7 +243,7 @@ message_info_save (CamelFolderSummary *summary, FILE *out, CamelMessageInfo *inf
 	if (camel_file_util_encode_string (out, einfo->href ? einfo->href : "") == -1)
 		return -1;
 
-	d(g_print ("%s:%s:%d: einfo->href = [%s]\n", __FILE__, G_GNUC_PRETTY_FUNCTION, __LINE__, einfo->href));
+	d(g_print ("%s:%s: einfo->href = [%s]\n", G_STRLOC, G_STRFUNC, einfo->href));
 
 	return 0;
 }
@@ -263,6 +267,22 @@ message_info_new_from_header (CamelFolderSummary *summary, struct _camel_header_
 	return info;
 }
 
+static void
+message_info_free (CamelFolderSummary *summary, CamelMessageInfo *info)
+{
+	CamelExchangeMessageInfo *einfo;
+
+	einfo = (CamelExchangeMessageInfo *)info;
+
+	g_free (einfo->href);
+	g_free (einfo->thread_index);
+
+	einfo->href = NULL;
+	einfo->thread_index = NULL;
+
+	CAMEL_FOLDER_SUMMARY_CLASS (parent_class)->message_info_free (summary, info);
+}
+
 static gboolean
 check_for_trash (CamelFolder *folder)
 {
