@@ -2438,20 +2438,18 @@ get_message (MailStub *stub, const char *folder_name, const char *uid)
 	if (mfld->type == MAIL_STUB_EXCHANGE_FOLDER_NOTES) {
 		status = get_stickynote (mse->ctx, NULL, mmsg->href,
 					 &body, &len);
-		if (!E2K_HTTP_STATUS_IS_SUCCESSFUL (status))
-			goto error;
 		content_type = g_strdup ("message/rfc822");
 	} else {
 		SoupBuffer *response;
 
 		status = e2k_context_get (mse->ctx, NULL, mmsg->href,
 					  &content_type, &response);
-		if (!E2K_HTTP_STATUS_IS_SUCCESSFUL (status))
-			goto error;
 		len = response->length;
 		body = g_strndup (response->data, response->length);
 		soup_buffer_free (response);
 	}
+	if (!E2K_HTTP_STATUS_IS_SUCCESSFUL (status))
+		goto error;
 
 	/* Public folders especially can contain non-email objects.
 	 * In that case, we fake the headers (which in this case
@@ -2729,7 +2727,7 @@ get_folder_info (MailStub *stub, const char *top, guint32 store_flags)
 	GArray *unread, *flags;
 	ExchangeHierarchy *hier;
 	EFolder *folder;
-	const char *type, *name, *uri, *path, *inbox_uri = NULL;
+	const char *type, *name, *uri, *path, *inbox_uri = NULL, *trash_uri = NULL, *sent_items_uri = NULL;
 	int unread_count, i, toplen = top ? strlen (top) : 0;
 	guint32 folder_flags = 0;
 	gboolean recursive, subscribed, info_fast;
@@ -2775,6 +2773,14 @@ get_folder_info (MailStub *stub, const char *top, guint32 store_flags)
 		inbox_uri = e_folder_get_physical_uri (mse->inbox);
 	}
 
+	if (mse->deleted_items) {
+		trash_uri = e_folder_get_physical_uri (mse->deleted_items);
+	}
+
+	if (mse->sent_items) {
+		sent_items_uri = e_folder_get_physical_uri (mse->sent_items);
+	}
+
 	if (folders) {
 		for (i = 0; i < folders->len; i++) {
 			folder = folders->pdata[i];
@@ -2848,6 +2854,12 @@ get_folder_info (MailStub *stub, const char *top, guint32 store_flags)
 			if (inbox_uri && !strcmp (uri, inbox_uri))
 				folder_flags |= CAMEL_STUB_FOLDER_SYSTEM|CAMEL_STUB_FOLDER_TYPE_INBOX;
 
+			if (trash_uri && !strcmp (uri, trash_uri))
+				folder_flags |= CAMEL_STUB_FOLDER_SYSTEM|CAMEL_STUB_FOLDER_TYPE_TRASH;
+
+			if (sent_items_uri && !strcmp (uri, sent_items_uri))
+				folder_flags |= CAMEL_STUB_FOLDER_SYSTEM|CAMEL_STUB_FOLDER_TYPE_SENT;
+
 			if (!e_folder_exchange_get_has_subfolders (folder)) {
 				d(printf ("%s:%d:%s - %s has no subfolders", __FILE__, __LINE__, __GNUC_PRETTY_FUNCTION__,
 					  name));
@@ -3294,6 +3306,8 @@ stub_connect (MailStub *stub, char *pwd)
 	mse->inbox = exchange_account_get_folder (account, uri);
 	uri = exchange_account_get_standard_uri (account, "deleteditems");
 	mse->deleted_items = exchange_account_get_folder (account, uri);
+	uri = exchange_account_get_standard_uri (account, "sentitems");
+	mse->sent_items = exchange_account_get_folder (account, uri);
 
 	/* Will be used for offline->online transition to initialize things for
 	   the first time */
